@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-import types
+import utils.py_version_compatibility as types
 from .interface.object_container import CloudioObjectContainer
 from .interface.attribute_container import CloudioAttributeContainer
 from .exception.invalid_cloudio_attribute_exception import InvalidCloudioAttributeException
@@ -197,10 +197,11 @@ class _InternalObject(CloudioObjectContainer, CloudioAttributeContainer):
                     # with a standard type)
                     #
                     # Check if it is a bool, int, float, string
-                    if isinstance(attr, bool)  or \
-                       isinstance(attr, int)   or \
-                       isinstance(attr, float) or \
-                       isinstance(attr, str):
+                    if isinstance(attr, types.BooleanType)  or \
+                       isinstance(attr, types.IntType)   or \
+                       isinstance(attr, types.FloatType) or \
+                       isinstance(attr, types.StringType) or \
+                       isinstance(attr, types.UnicodeType):
 
                         if field not in ('__module__', '__doc__'):  # Some excludes:
                             attribute = CloudioAttribute()
@@ -216,7 +217,7 @@ class _InternalObject(CloudioObjectContainer, CloudioAttributeContainer):
                                 raise CloudioModificationException('Duplicate name for fields')
 
                     elif isinstance(attr, types.MethodType) or \
-                         isinstance(attr, types.InstanceType) or \
+                         type(attr) or \
                          isinstance(attr, _InternalObject):
                         pass
                     else:
